@@ -371,6 +371,14 @@ class Repeat(object):
     maxPerRow = attr.ib(default=None, validator=is_valid_max_per_row)
 
 
+def is_valid_target(instance, attribute, value):
+    """
+    Check if a given attribute is a valid target
+    """
+    if not hasattr(value, "refId"):
+        raise ValueError(f"{attribute.name} should have 'refId' attribute")
+
+
 @attr.s
 class Target(object):
     """
@@ -920,7 +928,7 @@ class AlertCondition(object):
     :param type: CTYPE_*
     """
 
-    target = attr.ib(validator=instance_of(Target))
+    target = attr.ib(validator=is_valid_target)
     evaluator = attr.ib(validator=instance_of(Evaluator))
     timeRange = attr.ib(validator=instance_of(TimeRange))
     operator = attr.ib()
@@ -950,7 +958,9 @@ class AlertCondition(object):
 
 @attr.s
 class Alert(object):
-
+    """
+    :param alertRuleTags: Key Value pairs to be sent with Alert notifications.
+    """
     name = attr.ib()
     message = attr.ib()
     alertConditions = attr.ib()
@@ -960,6 +970,14 @@ class Alert(object):
     noDataState = attr.ib(default=STATE_NO_DATA)
     notifications = attr.ib(default=attr.Factory(list))
     gracePeriod = attr.ib(default='5m')
+    alertRuleTags = attr.ib(
+        default=attr.Factory(dict),
+        validator=attr.validators.deep_mapping(
+            key_validator=attr.validators.instance_of(str),
+            value_validator=attr.validators.instance_of(str),
+            mapping_validator=attr.validators.instance_of(dict),
+        )
+    )
 
     def to_json_data(self):
         return {
@@ -972,6 +990,7 @@ class Alert(object):
             'noDataState': self.noDataState,
             'notifications': self.notifications,
             'for': self.gracePeriod,
+            'alertRuleTags': self.alertRuleTags,
         }
 
 
@@ -1262,7 +1281,6 @@ class Graph(Panel):
     Generates Graph panel json structure.
 
     :param alert: List of AlertConditions
-    :param alertRuleTags: Key Value pairs to be sent with Alert notifications
     :param dataLinks: List of data links hooked to datapoints on the graph
     :param dataSource: DataSource's name
     :param minSpan: Minimum width for each panel
@@ -1270,7 +1288,6 @@ class Graph(Panel):
     """
 
     alert = attr.ib(default=None)
-    alertRuleTags = attr.ib(default=attr.Factory(dict))
     alertThreshold = attr.ib(default=True, validator=instance_of(bool))
     aliasColors = attr.ib(default=attr.Factory(dict))
     bars = attr.ib(default=False, validator=instance_of(bool))
@@ -1345,7 +1362,6 @@ class Graph(Panel):
         }
         if self.alert:
             graphObject['alert'] = self.alert
-            graphObject['alertRuleTags'] = self.alertRuleTags
             graphObject['thresholds'] = []
         if self.thresholds and self.alert:
             print("Warning: Graph threshold ignored as Alerts defined")
@@ -1503,7 +1519,8 @@ class AlertList(object):
             member_validator=attr.validators.instance_of(str),
             iterable_validator=attr.validators.instance_of(list)))
     description = attr.ib(default="", validator=instance_of(str))
-    gridPos = attr.ib(default=None, validator=instance_of(GridPos))
+    gridPos = attr.ib(
+        default=None, validator=attr.validators.optional(attr.validators.instance_of(GridPos)))
     id = attr.ib(default=None)
     limit = attr.ib(default=DEFAULT_LIMIT)
     links = attr.ib(
